unit ItemProp;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  StdCtrls, AddFlowLib_TLB, ExtCtrls;

type
  TItemPropDlg = class(TForm)
    CancelBtn: TButton;
    OKBtn: TButton;
    Label1: TLabel;
    ComboShape: TComboBox;
    Label2: TLabel;
    ComboAlignment: TComboBox;
    LabelComment: TStaticText;
    Label3: TLabel;
    Label4: TLabel;
    Label5: TLabel;
    Label6: TLabel;
    ComboArrowOrg: TComboBox;
    ComboArrowDst: TComboBox;
    ComboLinkStyle: TComboBox;
    ComboDrawStyle: TComboBox;
    Label7: TLabel;
    TextDrawWidth: TEdit;
    CheckTransparent: TCheckBox;
    CheckHiding: TCheckBox;
    CheckRigid: TCheckBox;
    CommandFillColor: TButton;
    ColorDialog1: TColorDialog;
    LabelFillColor: TStaticText;
    CommandDrawColor: TButton;
    LabelDrawColor: TStaticText;
    CommandForeColor: TButton;
    LabelForeColor: TStaticText;
    FrameUserData: TGroupBox;
    Label8: TLabel;
    Label9: TLabel;
    Label10: TLabel;
    Text1: TMemo;
    Text2: TMemo;
    Text3: TEdit;
    NodePictureGroup: TRadioGroup;
    procedure FormShow(Sender: TObject);
    procedure OKBtnClick(Sender: TObject);
    procedure CommandFillColorClick(Sender: TObject);
    procedure CommandDrawColorClick(Sender: TObject);
    procedure CommandForeColorClick(Sender: TObject);
  private
    { Dclarations prives }
  public
    { Dclarations publiques }
  end;

var
  ItemPropDlg: TItemPropDlg;

implementation

{$R *.DFM}

uses Main, Unit2, ActiveX, AxCtrls;

procedure TItemPropDlg.FormShow(Sender: TObject);
var
  temp: IPictureDisp;
begin
  with (frmNetwork.AddFlow1) do
  begin
    if ((SelectedNode = nil) and (SelectedLink = nil)) then
    begin
      LabelComment.Caption := 'No current item: therefore property settings are persistent. Next created items will received those property values by default.';

      ComboShape.ItemIndex := Shape;
      ComboAlignment.ItemIndex := Alignment;
      ComboArrowDst.ItemIndex := ArrowDst;
      ComboArrowOrg.ItemIndex := ArrowOrg;
      ComboLinkStyle.ItemIndex := LinkStyle;
      ComboDrawStyle.ItemIndex := DrawStyle;
      TextDrawWidth.Text := FloatToStr(DrawWidth);
      CheckTransparent.Checked := Transparent;
      CheckHiding.Checked := Hidden;
      LabelFillColor.Color := FillColor;
      LabelDrawColor.Color := DrawColor;
      LabelForeColor.Color := ForeColor;

      FrameUserData.Visible := False;
      Text1.Enabled := False;
      Text2.Enabled := False;
      Text3.Enabled := False;
      CommandFillColor.Enabled := True;
      CheckRigid.Enabled := False;
      ComboShape.Enabled := True;
      ComboAlignment.Enabled := True;
      ComboArrowDst.Enabled := True;
      ComboArrowOrg.Enabled := True;
      ComboLinkStyle.Enabled := True;
      CheckTransparent.Enabled := True;
    end
    else
    begin
      if (SelectedNode = nil) then  // We have a selected link
      begin
        LabelComment.Caption := 'The current item is a link. "Node-only" properties are disabled. Property settings will apply only to this current link.';

        ComboArrowDst.ItemIndex := SelectedLink.ArrowDst;
        ComboArrowOrg.ItemIndex := SelectedLink.ArrowOrg;
        ComboLinkStyle.ItemIndex := SelectedLink.LinkStyle;
        ComboDrawStyle.ItemIndex := SelectedLink.DrawStyle;
        TextDrawWidth.Text := FloatToStr(SelectedLink.DrawWidth);
        CheckHiding.Checked := SelectedLink.Hidden;
        CheckRigid.Checked := SelectedLink.Rigid;
        LabelDrawColor.Color := SelectedLink.DrawColor;
        LabelForeColor.Color := SelectedLink.ForeColor;
        Text1.Text := SelectedLink.Text;
        Text2.Text := SelectedLink.Tag;
        Text3.Text := IntToStr(SelectedLink.UserData);

        FrameUserData.Visible := True;
        Text1.Enabled := True;
        Text2.Enabled := True;
        Text3.Enabled := True;
        CommandFillColor.Enabled := False;
        CheckRigid.Enabled := True;
        ComboShape.Enabled := False;
        ComboAlignment.Enabled := False;
        ComboArrowDst.Enabled := True;
        ComboArrowOrg.Enabled := True;
        ComboLinkStyle.Enabled := True;
        CheckTransparent.Enabled := False;
      end
      else // We have a selected node
      begin
        LabelComment.Caption := 'The current item is a node. "Link-only" properties are disabled. Property settings will apply only to this current node.';

        ComboShape.ItemIndex := SelectedNode.Shape;
        ComboAlignment.ItemIndex := SelectedNode.Alignment;
        ComboDrawStyle.ItemIndex := SelectedNode.DrawStyle;
        TextDrawWidth.Text := FloatToStr(SelectedNode.DrawWidth);
        CheckTransparent.Checked := SelectedNode.Transparent;
        CheckHiding.Checked := SelectedNode.Hidden;
        LabelFillColor.Color := SelectedNode.FillColor;
        LabelDrawColor.Color := SelectedNode.DrawColor;
        LabelForeColor.Color := SelectedNode.ForeColor;
        Text1.Text := SelectedNode.Text;
        Text2.Text := SelectedNode.Tag;
        Text3.Text := IntToStr(SelectedNode.UserData);

        FrameUserData.Visible := True;
        Text1.Enabled := True;
        Text2.Enabled := True;
        Text3.Enabled := True;
        CommandFillColor.Enabled := True;
        CheckRigid.Enabled := False;
        ComboShape.Enabled := True;
        ComboAlignment.Enabled := True;
        ComboArrowDst.Enabled := False;
        ComboArrowOrg.Enabled := False;
        ComboLinkStyle.Enabled := False;
        CheckTransparent.Enabled := True;

        {Setting node picture}
        if SelectedNode.Picture = nil then
        begin
          NodePictureGroup.ItemIndex := 0;
        end
        else
        begin
          GetOlePicture(frmNetwork.Image2.Picture, temp);
          if SelectedNode.Picture = temp then
            NodePictureGroup.ItemIndex := 1
          else
          begin
            GetOlePicture(frmNetwork.Image3.Picture, temp);
            if SelectedNode.Picture = temp then
              NodePictureGroup.ItemIndex := 2
            else
            begin
              GetOlePicture(frmNetwork.Image4.Picture, temp);
              if SelectedNode.Picture = temp then
                NodePictureGroup.ItemIndex := 3;              
            end;
          end;
        end
      end
    end
  end
end;

procedure TItemPropDlg.OKBtnClick(Sender: TObject);
var
  temp: IPictureDisp;
begin
  with (frmNetwork.AddFlow1) do
  begin
    if ((SelectedNode = nil) and (SelectedLink = nil)) then
    begin
      Shape := ComboShape.ItemIndex;
      Alignment := ComboAlignment.ItemIndex;
      ArrowDst := ComboArrowDst.ItemIndex;
      ArrowOrg := ComboArrowOrg.ItemIndex;
      LinkStyle := ComboLinkStyle.ItemIndex;
      DrawStyle := ComboDrawStyle.ItemIndex;
      DrawWidth := StrToFloat(TextDrawWidth.Text);
      Transparent := CheckTransparent.Checked;
      Hidden := CheckHiding.Checked;
      FillColor := LabelFillColor.Color;
      DrawColor := LabelDrawColor.Color;
      ForeColor := LabelForeColor.Color;
    end
    else
    begin
      if (SelectedNode = nil) then
      begin
        SelectedLink.ArrowDst := ComboArrowDst.ItemIndex;
        SelectedLink.ArrowOrg := ComboArrowOrg.ItemIndex;
        SelectedLink.LinkStyle := ComboLinkStyle.ItemIndex;
        SelectedLink.DrawStyle := ComboDrawStyle.ItemIndex;
        SelectedLink.DrawWidth := StrToFloat(TextDrawWidth.Text);
        SelectedLink.Hidden := CheckHiding.Checked;
        SelectedLink.Rigid := CheckRigid.Checked;
        SelectedLink.DrawColor := LabelDrawColor.Color;
        SelectedLink.ForeColor := LabelForeColor.Color;
        SelectedLink.Text := Text1.Text;
        SelectedLink.Tag := Text2.Text;
        SelectedLink.UserData := StrToInt(Text3.Text);
      end
      else
      begin
        SelectedNode.Shape := ComboShape.ItemIndex;
        SelectedNode.Alignment := ComboAlignment.ItemIndex;
        SelectedNode.DrawStyle := ComboDrawStyle.ItemIndex; 
        SelectedNode.DrawWidth := StrToFloat(TextDrawWidth.Text);
        SelectedNode.Transparent := CheckTransparent.Checked;
        SelectedNode.Hidden := CheckHiding.Checked;
        SelectedNode.FillColor := LabelFillColor.Color;
        SelectedNode.DrawColor := LabelDrawColor.Color;
        SelectedNode.ForeColor := LabelForeColor.Color;
        SelectedNode.Text := Text1.Text;
        SelectedNode.Tag := Text2.Text;
        SelectedNode.UserData := StrToInt(Text3.Text);
        case NodePictureGroup.ItemIndex of
        0:
          SelectedNode.Picture := nil;
        1:
          begin
            GetOlePicture(frmNetwork.Image2.Picture, temp);
            SelectedNode.Picture := temp;
          end;
        2:
          begin
            GetOlePicture(frmNetwork.Image3.Picture, temp);
            SelectedNode.Picture := temp;
          end;
        3:
          begin
            GetOlePicture(frmNetwork.Image4.Picture, temp);
            SelectedNode.Picture := temp;
          end;
        end;
      end
    end
  end
end;

procedure TItemPropDlg.CommandFillColorClick(Sender: TObject);
begin
    ColorDialog1.Color := LabelFillColor.Color;
    if ColorDialog1.Execute then
      LabelFillColor.Color := ColorDialog1.Color;
end;

procedure TItemPropDlg.CommandDrawColorClick(Sender: TObject);
begin
    ColorDialog1.Color := LabelDrawColor.Color;
    if ColorDialog1.Execute then
      LabelDrawColor.Color := ColorDialog1.Color;
end;

procedure TItemPropDlg.CommandForeColorClick(Sender: TObject);
begin
    ColorDialog1.Color := LabelForeColor.Color;
    if ColorDialog1.Execute then
      LabelForeColor.Color := ColorDialog1.Color;
end;

end.
